==> wand-cli-2.4.1.tar.gz: wand-cli-2.4.1/wandbox/commands/frominput.py <==
import json
import os
import random
import sys

import requests
from prompt_toolkit.lexers import PygmentsLexer
from prompt_toolkit.shortcuts import prompt
from prompt_toolkit.styles.pygments import style_from_pygments_cls as sfpc
from pygments.styles import get_style_by_name, get_all_styles
from pygments.util import ClassNotFound
from rich.console import Console
from rich.syntax import Syntax

from wandbox.utilities.constants import init_lexers, lexers_dict, spinners
from wandbox.utilities.utils import Utils
from wandbox.utilities.compilers import compilers_
from wandbox.colorschemes import schemes, scheme_dict


class FromInput:
    def __init__(self):
        init_lexers()
        self.compilers = compilers_

        self.console = Console()
        self.output_json = dict()
        self.spinners = spinners
        self.themes = list(get_all_styles()) + schemes

    def get_lang(self):
        """Prompt the user for the programming language, close program if language not supported."""
        language = self.console.input("[green]Enter language:[/green] ").lower()

        if language not in self.compilers:
            self.console.print("Language is not supported!", style="bold red")
            Utils.close()
        return language

    def askinp(self, theme="solarized-dark"):
        """
        Make a multiline prompt for code input and send the code to the api.

        The compiled output from the api is returned.
        """
        language = self.get_lang()
        self.console.print(
            "Enter your code, (press esc + enter to run)\n", style="green"
        )
        if theme in self.themes:
            try:
                style = sfpc(get_style_by_name(theme))
            except ClassNotFound:
                style = scheme_dict[theme]()
        else:
            style = sfpc(get_style_by_name("solarized-dark"))

        code = prompt(
            "",
            lexer=PygmentsLexer(lexers_dict[language]),
            include_default_pygments_style=False,
            style=style,
            multiline=True,
        )

        self.output_json["code"] = code
        self.output_json["compiler"] = self.compilers[language]

        with self.console.status(
            "Compiling", spinner=random.choice(self.spinners)
        ) as status:
            headers = {"Content-type": "application/json"}
            data = requests.post(
                "https://wandbox.org/api/compile.json",
                headers=headers,
                data=json.dumps(self.output_json),
            ).json()
        return data


FromInput = FromInput()

==> wand-cli-2.4.5.tar.gz: wand-cli-2.4.5/wandbox/commands/frominput.py <==
import json
import os
import random
import sys

import requests
from prompt_toolkit.lexers import PygmentsLexer
from prompt_toolkit.shortcuts import prompt
from prompt_toolkit.styles.pygments import style_from_pygments_cls as sfpc
from pygments.styles import get_style_by_name, get_all_styles
from pygments.util import ClassNotFound
from rich.console import Console
from rich.syntax import Syntax

from wandbox.utilities.constants import init_lexers, lexers_dict, spinners
from wandbox.utilities.utils import Utils
from wandbox.utilities.compilers import compilers_
from wandbox.colorschemes import schemes, scheme_dict


class FromInput:
    def __init__(self):
        init_lexers()
        self.compilers = compilers_

        self.console = Console()
        self.output_json = {}
        self.spinners = spinners
        self.themes = list(get_all_styles()) + schemes

    def get_lang(self, language):
        """Get the programming language from argument, close program if language not supported."""
        if language not in self.compilers:
            self.console.print("Language is not supported!", style="bold red")
            Utils.close()
        return language

    def askinp(self, theme, language):
        """
        Make a multiline prompt for code input and send the code to the api.

        The compiled output from the api is returned.
        """
        language = self.get_lang(language)
        self.console.print(
            "Enter your code, (press esc + enter to run)\n", style="green"
        )
        if theme in self.themes:
            try:
                style = sfpc(get_style_by_name(theme))
            except ClassNotFound:
                style = scheme_dict[theme]()
        else:
            style = sfpc(get_style_by_name("monokai"))

        code = prompt(
            "",
            lexer=PygmentsLexer(lexers_dict[language]),
            include_default_pygments_style=False,
            style=style,
            multiline=True,
        )

        self.output_json["code"] = code
        self.output_json["compiler"] = self.compilers[language]

        with self.console.status(
            "Compiling", spinner=random.choice(self.spinners)
        ) as status:
            headers = {"Content-type": "application/json"}
            data = requests.post(
                "https://wandbox.org/api/compile.json",
                headers=headers,
                data=json.dumps(self.output_json),
            ).json()
        return data


FromInput = FromInput()
